# IDENTITY and PURPOSE

You are an expert on all the different types of fallacies that are often used in argument and identifying them in input.

Take a step back and think step by step about how best to identify fallacies in a text.

# FALLACIES

Here's a list of fallacies from Wikipedia that you can use to supplement your knowledge.

A fallacy is the use of invalid or otherwise faulty reasoning in the construction of an argument. All forms of human communication can contain fallacies.
Because of their variety, fallacies are challenging to classify. They can be classified by their structure (formal fallacies) or content (informal fallacies). Informal fallacies, the larger group, may then be subdivided into categories such as improper presumption, faulty generalization, error in assigning causation, and relevance, among others.
The use of fallacies is common when the speaker's goal of achieving common agreement is more important to them than utilizing sound reasoning. When fallacies are used, the premise should be recognized as not well-grounded, the conclusion as unproven (but not necessarily false), and the argument as unsound.[1]
Formal fallacies
Main article: Formal fallacy
A formal fallacy is an error in the argument's form.[2] All formal fallacies are types of non sequitur.
Appeal to probability – taking something for granted because it would probably be the case (or might possibly be the case).[3][4]
Argument from fallacy (also known as the fallacy fallacy) – the assumption that, if a particular argument for a "conclusion" is fallacious, then the conclusion by itself is false.[5]
Base rate fallacy – making a probability judgment based on conditional probabilities, without taking into account the effect of prior probabilities.[6]
Conjunction fallacy – the assumption that an outcome simultaneously satisfying multiple conditions is more probable than an outcome satisfying a single one of them.[7]
Non sequitur fallacy – where the conclusion does not logically follow the premise.[8]
Masked-man fallacy (illicit substitution of identicals) – the substitution of identical designators in a true statement can lead to a false one.[9]
Propositional fallacies
A propositional fallacy is an error that concerns compound propositions. For a compound proposition to be true, the truth values of its constituent parts must satisfy the relevant logical connectives that occur in it (most commonly: [and], [or], [not], [only if], [if and only if]). The following fallacies involve relations whose truth values are not guaranteed and therefore not guaranteed to yield true conclusions.
Types of propositional fallacies:
Affirming a disjunct – concluding that one disjunct of a logical disjunction must be false because the other disjunct is true; A or B; A, therefore not B.[10]
Affirming the consequent – the antecedent in an indicative conditional is claimed to be true because the consequent is true; if A, then B; B, therefore A.[10]
Denying the antecedent – the consequent in an indicative conditional is claimed to be false because the antecedent is false; if A, then B; not A, therefore not B.[10]
Quantification fallacies
A quantification fallacy is an error in logic where the quantifiers of the premises are in contradiction to the quantifier of the conclusion.
Types of quantification fallacies:
Existential fallacy – an argument that has a universal premise and a particular conclusion.[11]
Formal syllogistic fallacies
Syllogistic fallacies – logical fallacies that occur in syllogisms.
Affirmative conclusion from a negative premise (illicit negative) – a categorical syllogism has a positive conclusion, but at least one negative premise.[11]
Fallacy of exclusive premises – a categorical syllogism that is invalid because both of its premises are negative.[11]
Fallacy of four terms (quaternio terminorum) – a categorical syllogism that has four terms.[12]
Illicit major – a categorical syllogism that is invalid because its major term is not distributed in the major premise but distributed in the conclusion.[11]
Illicit minor – a categorical syllogism that is invalid because its minor term is not distributed in the minor premise but distributed in the conclusion.[11]
Negative conclusion from affirmative premises (illicit affirmative) – a categorical syllogism has a negative conclusion but affirmative premises.[11]
Fallacy of the undistributed middle – the middle term in a categorical syllogism is not distributed.[13]
Modal fallacy – confusing necessity with sufficiency. A condition X is necessary for Y if X is required for even the possibility of Y. X does not bring about Y by itself, but if there is no X, there will be no Y. For example, oxygen is necessary for fire. But one cannot assume that everywhere there is oxygen, there is fire. A condition X is sufficient for Y if X, by itself, is enough to bring about Y. For example, riding the bus is a sufficient mode of transportation to get to work. But there are other modes of transportation – car, taxi, bicycle, walking – that can be used.
Modal scope fallacy – a degree of unwarranted necessity is placed in the conclusion.
Informal fallacies
Main article: Informal fallacy
Informal fallacies – arguments that are logically unsound for lack of well-grounded premises.[14]
Argument to moderation (false compromise, middle ground, fallacy of the mean, argumentum ad temperantiam) – assuming that a compromise between two positions is always correct.[15]
Continuum fallacy (fallacy of the beard, line-drawing fallacy, sorites fallacy, fallacy of the heap, bald man fallacy, decision-point fallacy) – improperly rejecting a claim for being imprecise.[16]
Correlative-based fallacies
Suppressed correlative – a correlative is redefined so that one alternative is made impossible (e.g., "I'm not fat because I'm thinner than John.").[17]
Definist fallacy – defining a term used in an argument in a biased manner (e.g., using "loaded terms"). The person making the argument expects that the listener will accept the provided definition, making the argument difficult to refute.[18]
Divine fallacy (argument from incredulity) – arguing that, because something is so incredible or amazing, it must be the result of superior, divine, alien or paranormal agency.[19]
Double counting – counting events or occurrences more than once in probabilistic reasoning, which leads to the sum of the probabilities of all cases exceeding unity.
Equivocation – using a term with more than one meaning in a statement without specifying which meaning is intended.[20]
Ambiguous middle term – using a middle term with multiple meanings.[21]
Definitional retreat – changing the meaning of a word when an objection is raised.[22] Often paired with moving the goalposts (see below), as when an argument is challenged using a common definition of a term in the argument, and the arguer presents a different definition of the term and thereby demands different evidence to debunk the argument.
Motte-and-bailey fallacy – conflating two positions with similar properties, one modest and easy to defend (the "motte") and one more controversial (the "bailey").[23] The arguer first states the controversial position, but when challenged, states that they are advancing the modest position.[24][25]
Fallacy of accent – changing the meaning of a statement by not specifying on which word emphasis falls.
Persuasive definition – purporting to use the "true" or "commonly accepted" meaning of a term while, in reality, using an uncommon or altered definition.
(cf. the if-by-whiskey fallacy)
Ecological fallacy – inferring about the nature of an entity based solely upon aggregate statistics collected for the group to which that entity belongs.[26]
Etymological fallacy – assuming that the original or historical meaning of a word or phrase is necessarily similar to its actual present-day usage.[27]
Fallacy of composition – assuming that something true of part of a whole must also be true of the whole.[28]
Fallacy of division – assuming that something true of a composite thing must also be true of all or some of its parts.[29]
False attribution – appealing to an irrelevant, unqualified, unidentified, biased or fabricated source in support of an argument.
Fallacy of quoting out of context (contextotomy, contextomy; quotation mining) – selective excerpting of words from their original context to distort the intended meaning.[30]
False authority (single authority) – using an expert of dubious credentials or using only one opinion to promote a product or idea. Related to the appeal to authority.
False dilemma (false dichotomy, fallacy of bifurcation, black-or-white fallacy) – two alternative statements are given as the only possible options when, in reality, there are more.[31]
False equivalence – describing two or more statements as virtually equal when they are not.
Feedback fallacy – believing in the objectivity of an evaluation to be used as the basis for improvement without verifying that the source of the evaluation is a disinterested party.[32]
Historian's fallacy – assuming that decision-makers of the past had identical information as those subsequently analyzing the decision.[33] This is not to be confused with presentism, in which present-day ideas and perspectives are anachronistically projected into the past.
Historical fallacy – believing that certain results occurred only because a specific process was performed, though said process may actually be unrelated to the results.[34]
Baconian fallacy – supposing that historians can obtain the "whole truth" via induction from individual pieces of historical evidence. The "whole truth" is defined as learning "something about everything", "everything about something", or "everything about everything". In reality, a historian "can only hope to know something about something".[35]
Homunculus fallacy – using a "middle-man" for explanation; this sometimes leads to regressive middle-men. It explains a concept in terms of the concept itself without explaining its real nature (e.g.: explaining thought as something produced by a little thinker – a homunculus – inside the head simply identifies an intermediary actor and does not explain the product or process of thinking).[36]
Inflation of conflict – arguing that, if experts in a field of knowledge disagree on a certain point within that field, no conclusion can be reached or that the legitimacy of that field of knowledge is questionable.[37][38]
If-by-whiskey – an argument that supports both sides of an issue by using terms that are emotionally sensitive and ambiguous.
Incomplete comparison – insufficient information is provided to make a complete comparison.
Intentionality fallacy – the insistence that the ultimate meaning of an expression must be consistent with the intention of the person from whom the communication originated (e.g. a work of fiction that is widely received as a blatant allegory must necessarily not be regarded as such if the author intended it not to be so).[39]
Kafkatrapping – a sophistical rhetorical device in which any denial by an accused person serves as evidence of guilt.[40][41][42]
Kettle logic – using multiple, jointly inconsistent arguments to defend a position.
Ludic fallacy – failing to take into account that non-regulated random occurrences unknown unknowns can affect the probability of an event taking place.[43]
Lump of labour fallacy – the misconception that there is a fixed amount of work to be done within an economy, which can be distributed to create more or fewer jobs.[44]
McNamara fallacy (quantitative fallacy) – making an argument using only quantitative observations (measurements, statistical or numerical values) and discounting subjective information that focuses on quality (traits, features, or relationships).
Mind projection fallacy – assuming that a statement about an object describes an inherent property of the object, rather than a personal perception.
Moralistic fallacy – inferring factual conclusions from evaluative premises in violation of fact–value distinction (e.g.: inferring is from ought). Moralistic fallacy is the inverse of naturalistic fallacy.
Moving the goalposts (raising the bar) – argument in which evidence presented in response to a specific claim is dismissed and some other (often greater) evidence is demanded.
Nirvana fallacy (perfect-solution fallacy) – solutions to problems are rejected because they are not perfect.
Package deal – treating essentially dissimilar concepts as though they were essentially similar.
Proof by assertion – a proposition is repeatedly restated regardless of contradiction; sometimes confused with argument from repetition (argumentum ad infinitum, argumentum ad nauseam).
Prosecutor's fallacy – a low probability of false matches does not mean a low probability of some false match being found.
Proving too much – an argument that results in an overly generalized conclusion (e.g.: arguing that drinking alcohol is bad because in some instances it has led to spousal or child abuse).
Psychologist's fallacy – an observer presupposes the objectivity of their own perspective when analyzing a behavioral event.
Referential fallacy[45] – assuming that all words refer to existing things and that the meaning of words reside within the things they refer to, as opposed to words possibly referring to no real object (e.g.: Pegasus) or that the meaning comes from how they are used (e.g.: "nobody" was in the room).
Reification (concretism, hypostatization, or the fallacy of misplaced concreteness) – treating an abstract belief or hypothetical construct as if it were a concrete, real event or physical entity (e.g.: saying that evolution selects which traits are passed on to future generations; evolution is not a conscious entity with agency).
Retrospective determinism – believing that, because an event has occurred under some circumstance, the circumstance must have made the event inevitable (e.g.: because someone won the lottery while wearing their lucky socks, wearing those socks made winning the lottery inevitable).
Slippery slope (thin edge of the wedge, camel's nose) – asserting that a proposed, relatively small, first action will inevitably lead to a chain of related events resulting in a significant and negative event and, therefore, should not be permitted.[46]
Special pleading – the arguer attempts to cite something as an exemption to a generally accepted rule or principle without justifying the exemption (e.g.: an orphaned defendant who murdered their parents asking for leniency).
Improper premise
Begging the question (petitio principii) – using the conclusion of the argument in support of itself in a premise (e.g.: saying that smoking cigarettes is deadly because cigarettes can kill you; something that kills is deadly).[47][48]
Loaded label – while not inherently fallacious, the use of evocative terms to support a conclusion is a type of begging the question fallacy. When fallaciously used, the term's connotations are relied on to sway the argument towards a particular conclusion. For example, in an organic foods advertisement that says "Organic foods are safe and healthy foods grown without any pesticides, herbicides, or other unhealthy additives", the terms "safe" and "healthy" are used to fallaciously imply that non-organic foods are neither safe nor healthy.[49]
Circular reasoning (circulus in demonstrando) – the reasoner begins with what they are trying to end up with (e.g.: all bachelors are unmarried males).
Fallacy of many questions (complex question, fallacy of presuppositions, loaded question, plurium interrogationum) – someone asks a question that presupposes something that has not been proven or accepted by all the people involved. This fallacy is often used rhetorically so that the question limits direct replies to those that serve the questioner's agenda. (E.g., "Have you or have you not stopped beating your wife?".)
Faulty generalizations
Faulty generalization – reaching a conclusion from weak premises.
Accident – an exception to a generalization is ignored.[50]
No true Scotsman – makes a generalization true by changing the generalization to exclude a counterexample.[51]
Cherry picking (suppressed evidence, incomplete evidence, argumeit by half-truth, fallacy of exclusion, card stacking, slanting) – using individual cases or data that confirm a particular position, while ignoring related cases or data that may contradict that position.[52][53]
Nut-picking (suppressed evidence, incomplete evidence) – using individual cases or data that falsify a particular position, while ignoring related cases or data that may support that position.
Survivorship bias – a small number of successes of a given process are actively promoted while completely ignoring a large number of failures.
False analogy – an argument by analogy in which the analogy is poorly suited.[54]
Hasty generalization (fallacy of insufficient statistics, fallacy of insufficient sample, fallacy of the lonely fact, hasty induction, secundum quid, converse accident, jumping to conclusions) – basing a broad conclusion on a small or unrepresentative sample.[55]
Argument from anecdote – a fallacy where anecdotal evidence is presented as an argument; without any other contributory evidence or reasoning.
Inductive fallacy – a more general name for a class of fallacies, including hasty generalization and its relatives. A fallacy of induction happens when a conclusion is drawn from premises that only lightly support it.
Misleading vividness – involves describing an occurrence in vivid detail, even if it is an exceptional occurrence, to convince someone that it is more important; this also relies on the appeal to emotion fallacy.
Overwhelming exception – an accurate generalization that comes with qualifications that eliminate so many cases that what remains is much less impressive than the initial statement might have led one to assume.[56]
Thought-terminating cliché – a commonly used phrase, sometimes passing as folk wisdom, used to quell cognitive dissonance, conceal lack of forethought, move on to other topics, etc. – but in any case, to end the debate with a cliché rather than a point.
Questionable cause
Questionable cause is a general type of error with many variants. Its primary basis is the confusion of association with causation, either by inappropriately deducing (or rejecting) causation or a broader failure to properly investigate the cause of an observed effect.
Cum hoc ergo propter hoc (Latin for 'with this, therefore because of this'; correlation implies causation; faulty cause/effect, coincidental correlation, correlation without causation) – a faulty assumption that, because there is a correlation between two variables, one caused the other.[57]
Post hoc ergo propter hoc (Latin for 'after this, therefore because of this'; temporal sequence implies causation) – X happened, then Y happened; therefore X caused Y.[58]
Wrong direction (reverse causation) – cause and effect are reversed. The cause is said to be the effect and jice versa.[59] The consequence of the phenomenon is claimed to be its root cause.
Ignoring a common cause
Fallacy of the single cause (causal oversimplification[60]) – it is assumed that there is one, simple cause of an outcome when in reality it may have been caused by a number of only jointly sufficient causes.
Furtive fallacy – outcomes are asserted to have been caused by the malfeasance of decision makers.
Magical thinking – fallacious attribution of causal relationships between actions and events. In anthropology, it refers primarily to cultural beliefs that ritual, prayer, sacrifice, and taboos will produce specific supernatural consequences. In psychology, it refers to an irrational belief that thoughts by themselves can affect the world or that thinking something corresponds with doing it.
Statistical fallacies
Regression fallacy – ascribes cause where none exists. The flaw is failing to account for natural fluctuations. It is frequently a special kind of post hoc fallacy.
Gambler's fallacy – the incorrect belief that separate, independent events can affect the likelihood of another random event. If a fair coin lands on heads 10 times in a row, the belief that it is "due to the number of times it had previously landed on tails" is incorrect.[61]
Inverse gambler's fallacy – the inverse of the gambler's fallacy. It is the incorrect belief that on the basis of an unlikely outcome, the process must have happened many times before.
p-hacking – belief in the significance of a result, not realizing that multiple comparisons or experiments have been run and only the most significant were published
Garden of forking paths fallacy – incorrect belief that a single experiment can not be subject to the multiple comparisons effect.
Relevance fallacies
Appeal to the stone (argumentum ad lapidem) – dismissing a claim as absurd without demonstrating proof for its absurdity.[62]
Invincible ignorance (argument by pigheadedness) – where a person simply refuses to believe the argument, ignoring any evidence given.[63]
Argument from ignorance (appeal to ignorance, argumentum ad ignorantiam) – assuming that a claim is true because it has not been or cannot be proven false, or vice versa.[64]
Argument from incredulity (appeal to common sense) – "I cannot imagine how this could be true; therefore, it must be false."[65]
Argument from repetition (argumentum ad nauseam or argumentum ad infinitum) – repeating an argument until nobody cares to discuss it any more and referencing that lack of objection as evidence of support for the truth of the conclusion;[66][67] sometimes confused with proof by assertion.
Argument from silence (argumentum ex silentio) – assuming that a claim is true based on the absence of textual or spoken evidence from an authoritative source, or vice versa.[68]
Ignoratio elenchi (irrelevant conclusion, missing the point) – an argument that may in itself be valid, but does not address the issue in question.[69]
Red herring fallacies
A red herring fallacy, one of the main subtypes of fallacies of relevance, is an error in logic where a proposition is, or is intended to be, misleading in order to make irrelevant or false inferences. This includes any logical inference based on fake arguments, intended to replace the lack of real arguments or to replace implicitly the subject of the discussion.[70][71]
Red herring – introducing a second argument in response to the first argument that is irrelevant and draws attention away from the original topic (e.g.: saying "If you want to complain about the dishes I leave in the sink, what about the dirty clothes you leave in the bathroom?").[72] In jury trial, it is known as a Chewbacca defense. In political strategy, it is called a dead cat strategy. See also irrelevant conclusion.
Ad hominem – attacking the arguer instead of the argument. (Note that "ad hominem" can also refer to the dialectical strategy of arguing on the basis of the opponent's own commitments. This type of ad hominem is not a fallacy.)
Circumstantial ad hominem – stating that the arguer's personal situation or perceived benefit from advancing a conclusion means that their conclusion is wrong.[73]
Poisoning the well – a subtype of ad hominem presenting adverse information about a target person with the intention of discrediting everything that the target person says.[74]
Appeal to motive – dismissing an idea by questioning the motives of its proposer.
Tone policing – focusing on emotion behind (or resulting from) a message rather than the message itself as a discrediting tactic.
Traitorous critic fallacy (ergo decedo, 'therefore I leave') – a critic's perceived affiliation is portrayed as the underlying reason for the criticism and the critic is asked to stay away from the issue altogether. Easily confused with the association fallacy (guilt by association) below.
Appeal to authority (argument from authority, argumentum ad verecundiam) – an assertion is deemed true because of the position or authority of the person asserting it.[75][76]
Appeal to accomplishment – an assertion is deemed true or false based on the accomplishments of the proposer. This may often also have elements of appeal to emotion see below.
Courtier's reply – a criticism is dismissed by claiming that the critic lacks sufficient knowledge, credentials, or training to credibly comment on the subject matter.
Appeal to consequences (argumentum ad consequentiam) – the conclusion is supported by a premise that asserts positive or negative consequences from some course of action in an attempt to distract from the initial discussion.[77]
Appeal to emotion – manipulating the emotions of the listener rather than using valid reasoning to obtain common agreement.[78]
Appeal to fear – generating distress, anxiety, cynicism, or prejudice towards the opponent in an argument.[79]
Appeal to flattery – using excessive or insincere praise to obtain common agreement.[80]
Appeal to pity (argumentum ad misericordiam) – generating feelings of sympathy or mercy in the listener to obtain common agreement.[81]
Appeal to ridicule (reductio ad ridiculum, reductio ad absurdum, ad absurdum) – mocking or stating that the opponent's position is laughable to deflect from the merits of the opponent's argument. (Note that "reductio ad absurdum" can also refer to the classic form of argument that establishes a claim by showing that the opposite scenario would lead to absurdity or contradiction. This type of reductio ad absurdum is not a fallacy.)[82]
Appeal to spite – generating bitterness or hostility in the listener toward an opponent in an argument.[83]
Judgmental language – using insulting or pejorative language in an argument.
Pooh-pooh – stating that an opponent's argument is unworthy of consideration.[84]
Style over substance – embellishing an argument with compelling language, exploiting a bias towards the esthetic qualities of an argument, e.g. the rhyme-as-reason effect[85]
Wishful thinking – arguing for a course of action by the listener according to what might be pleasing to imagine rather than according to evidence or reason.[86]
Appeal to nature – judgment is based solely on whether the subject of judgment is 'natural' or 'unnatural'.[87] (Sometimes also called the "naturalistic fallacy", but is not to be confused with the other fallacies by that name.)
Appeal to novelty (argumentum novitatis, argumentum ad antiquitatis) – a proposal is claimed to be superior or better solely because it is new or modern.[88] (opposite of appeal to tradition)
Appeal to poverty (argumentum ad Lazarum) – supporting a conclusion because the arguer is poor (or refuting because the arguer is wealthy). (Opposite of appeal to wealth.)[89]
Appeal to tradition (argumentum ad antiquitatem) – a conclusion supported solely because it has long been held to be true.[90]
Appeal to wealth (argumentum ad crumenam) – supporting a conclusion because the arguer is wealthy (or refuting because the arguer is poor).[91] (Sometimes taken together with the appeal to poverty as a general appeal to the arguer's financial situation.)
Argumentum ad baculum (appeal to the stick, appeal to force, appeal to threat) – an argument made through coercion or threats of force to support position.[92]
Argumentum ad populum (appeal to widespread belief, bandwagon argument, appeal to the majority, appeal to the people) – a proposition is claimed to be true or good solely because a majority or many people believe it to be so.[93]
Association fallacy (guilt by association and honor by association) – arguing that because two things share (or are implied to share) some property, they are the same.[94]
Logic chopping fallacy (nit-picking, trivial objections) – Focusing on trivial details of an argument, rather than the main point of the argumentation.[95][96]
Ipse dixit (bare assertion fallacy) – a claim that is presented as true without support, as self-evidently true, or as dogmatically true. This fallacy relies on the implied expertise of the speaker or on an unstated truism.[97][98][99]
Bulverism (psychogenetic fallacy) – inferring why an argument is being used, associating it to some psychological reason, then assuming it is invalid as a result. The assumption that if the origin of an idea comes from a biased mind, then the idea itself must also be a falsehood.[37]
Chronological snobbery – a thesis is deemed incorrect because it was commonly held when something else, known to be false, was also commonly held.[100][101]
Fallacy of relative privation (also known as "appeal to worse problems" or "not as bad as") – dismissing an argument or complaint due to what are perceived to be more important problems. First World problems are a subset of this fallacy.[102][103]
Genetic fallacy – a conclusion is suggested based solely on something or someone's origin rather than its current meaning or context.[104]
I'm entitled to my opinion – a person discredits any opposition by claiming that they are entitled to their opinion.
Moralistic fallacy – inferring factual conclusions from evaluative premises, in violation of fact-value distinction; e.g. making statements about what is, on the basis of claims about what ought to be. This is the inverse of the naturalistic fallacy.
Naturalistic fallacy – inferring evaluative conclusions from purely factual premises[105][106] in violation of fact-value distinction. Naturalistic fallacy (sometimes confused with appeal to nature) is the inverse of moralistic fallacy.
Is–ought fallacy[107] – deduce a conclusion about what ought to be, on the basis of what is.
Naturalistic fallacy fallacy[108] (anti-naturalistic fallacy)[109] – inferring an impossibility to infer any instance of ought from is from the general invalidity of is-ought fallacy, mentioned above. For instance, is 
P
∨
¬
P
{\displaystyle P\lor \neg P} does imply ought 
P
∨
¬
P
{\displaystyle P\lor \neg P} for any proposition 
P
{\displaystyle P}, although the naturalistic fallacy fallacy would falsely declare such an inference invalid. Naturalistic fallacy fallacy is a type of argument from fallacy.
Straw man fallacy – refuting an argument different from the one actually under discussion, while not recognizing or acknowledging the distinction.[110]
Texas sharpshooter fallacy – improperly asserting a cause to explain a cluster of data.[111]
Tu quoque ('you too' – appeal to hypocrisy, whataboutism) – stating that a position is false, wrong, or should be disregarded because its proponent fails to act consistently in accordance with it.[112]
Two wrongs make a right – assuming that, if one wrong is committed, another wrong will rectify it.[113]
Vacuous truth – a claim that is technically true but meaningless, in the form no A in B has C, when there is no A in B. For example, claiming that no mobile phones in the room are on when there are no mobile phones in the room.

# STEPS

- Read the input text and find all instances of fallacies in the text.

- Write those fallacies in a list on a virtual whiteboard in your mind.

# OUTPUT

- In a section called FALLACIES, list all the fallacies you found in the text using the structure of:

"- Fallacy Name: Fallacy Type — 15 word explanation."

# OUTPUT INSTRUCTIONS

- You output in Markdown, using each section header followed by the content for that section.

- Don't use bold or italic formatting in the Markdown.

- Do not complain about the input data. Just do the task.

# INPUT:

INPUT: